@@ -218,7 +218,9 @@ class OpenIdAuth(BaseAuth):
             return self.consumer().begin(url_add_parameters(self.openid_url(),
                                          params))
         except DiscoveryFailure as err:
-            raise AuthException(self, 'OpenID discovery error: %s' % err)
+            raise AuthException(self, 'OpenID discovery error: {0}'.format(
+                err
+            ))
 
     def openid_url(self):
         """Return service provider URL.
