@@ -16,9 +16,9 @@ class ReadabilityOAuth(BaseOAuth1):
     """Readability OAuth authentication backend"""
     name = 'readability'
     ID_KEY = 'username'
-    AUTHORIZATION_URL = '%s/oauth/authorize/' % READABILITY_API
-    REQUEST_TOKEN_URL = '%s/oauth/request_token/' % READABILITY_API
-    ACCESS_TOKEN_URL = '%s/oauth/access_token/' % READABILITY_API
+    AUTHORIZATION_URL = '{0}/oauth/authorize/'.format(READABILITY_API)
+    REQUEST_TOKEN_URL = '{0}/oauth/request_token/'.format(READABILITY_API)
+    ACCESS_TOKEN_URL = '{0}/oauth/access_token/'.format(READABILITY_API)
     EXTRA_DATA = [('date_joined', 'date_joined'),
                   ('kindle_email_address', 'kindle_email_address'),
                   ('avatar_url', 'avatar_url'),
