@@ -11,8 +11,10 @@ def save_status_to_session(strategy, pipeline_index, *args, **kwargs):
 def partial(func):
     @wraps(func)
     def wrapper(strategy, pipeline_index, *args, **kwargs):
-        values = strategy.to_session(pipeline_index, *args, **kwargs)
-        strategy.session_set('partial_pipeline', values)
-        return func(strategy=strategy, pipeline_index=pipeline_index,
-                    *args, **kwargs)
+        out = func(strategy=strategy, pipeline_index=pipeline_index,
+                    *args, **kwargs) or {}
+        if not isinstance(out, dict):
+            values = strategy.to_session(pipeline_index, *args, **kwargs)
+            strategy.session_set('partial_pipeline', values)
+        return out
     return wrapper
